      REM =====================================================================
      REM          Huge Integer Math and Encryption library
      REM                    ( H I M E . d l l )
      REM                  (C) 2002-2012 DevOTechS
      REM               e-mail: support@devotechs.com
      REM
      REM         Demo program to use HIME.dll from BBC BASIC
      REM              HIME.dll can be downloaded from:
      REM                  http://www.devotechs.com
      REM
      REM =====================================================================
      
      INSTALL @lib$+"HIMELIB"
      
      keyfile% = OPENIN(@lib$+"himekey.txt")
      IF keyfile% key$ = GET$#keyfile% : CLOSE #keyfile% ELSE key$ = ""
      PROC_himeinit(key$) : REM Licence key to suppress nag dialogue
      
      REM Display HIME version:
      SYS `hi_Version` TO version%
      PRINT "HIME version is "; version% '
      
      REM Declare some registers:
      reg1% = 1
      reg2% = 2
      reg3% = 3
      reg4% = 4
      
      REM Load some large numbers into registers:
      PROC_hiputdec(reg1%, "1234567890123456789012345678901234567890")
      PROC_hiputdec(reg2%, "555555555555555555555555555555")
      
      REM Display the numbers:
      PRINT "First number is:  " FN_higetdec(reg1%)
      PRINT "Second number is: " FN_higetdec(reg2%)
      
      REM Display in hexdecimal:
      PRINT "First number in hex is:  " FN_higethex(reg1%)
      PRINT "Second number in hex is: " FN_higethex(reg2%)
      
      REM Add the numbers together:
      SYS `hi_Add`, ^reg1%, ^reg2%, ^reg3%
      PRINT "Sum is: " FN_higetdec(reg3%)
      
      REM Multiply the numbers:
      SYS `hi_Mul`, ^reg1%, ^reg2%, ^reg3%
      PRINT "Product is: " FN_higetdec(reg3%)
      
      REM Find quotient and remainder:
      SYS `hi_Div`, ^reg1%, ^reg2%, ^reg3%, ^reg4%
      PRINT "Quotient is:  " FN_higetdec(reg3%)
      PRINT "Remainder is: " FN_higetdec(reg4%)
      
      REM Find greatest common divisor:
      SYS `hi_GCD`, ^reg1%, ^reg2%, ^reg3%
      PRINT "Greatest Common Divisor is: " FN_higetdec(reg3%) '
      
      REM Generate RSA keys:
      bitsmod% = 256 : REM Number of bits of RSA modulus
      nprimet% = 4   : REM Number of prime tests
      PROC_hiput(reg1%, "") : REM Clear the public key
      SYS `hi_GenerateRSAKeys`, ^bitsmod%, ^nprimet%, ^reg1%, ^reg2%, ^reg3%
      PRINT "Public key (hex) is: " FN_higethex(reg1%)
      PRINT "Private key (hex) is: " FN_higethex(reg2%)
      PRINT "Modulus (hex) is: " FN_higethex(reg3%) '
      
      REM Encrypt and decrypt a string using RSA:
      plaintext$ = "Hello world!"
      PROC_hiput(reg4%, plaintext$)
      SYS `hi_RSA_Pad_PKCS1_1_5`, ^reg4%, ^reg3%, ^reg4% TO res%
      IF res%=1 ERROR 100, "Plaintext string is too long"
      SYS `hi_Encrypt_RSA`, ^reg4%, ^reg1%, ^reg3%, ^reg4%
      PRINT "Ciphertext (hex) is: " FN_higethex(reg4%)
      
      SYS `hi_Decrypt_RSA`, ^reg4%, ^reg2%, ^reg3%, ^reg4%
      SYS `hi_RSA_Unpad_PKCS1_1_5`, ^reg4%, ^reg4%
      PRINT "Decrypted text is: """ FN_higet(reg4%) """"
      
      END
